@@ -180,7 +180,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const QString &sgroup)
   KatePluginManager::self()->enableAllPluginsGUI (this, sconfig);
 
   // connect documents menu aboutToshow
-  documentMenu = (QMenu*)factory()->container("documents", this);
+  documentMenu = (QMenu*)factory()->container("go", this);
   connect(documentMenu, SIGNAL(aboutToShow()), this, SLOT(documentMenuAboutToShow()));
 
   documentsGroup = new QActionGroup(documentMenu);
@@ -231,8 +231,7 @@ KateMainWindow::~KateMainWindow()
 void KateMainWindow::setupImportantActions ()
 {
   // settings
-  m_paShowStatusBar = KStandardAction::showStatusbar(this, SLOT(toggleShowStatusBar()), this);
-  actionCollection()->addAction( "settings_show_statusbar", m_paShowStatusBar);
+  m_paShowStatusBar = KStandardAction::showStatusbar(this, SLOT(toggleShowStatusBar()), actionCollection());
   m_paShowStatusBar->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
 
   m_paShowPath = new KToggleAction( i18n("Sho&w Path"), this );
@@ -345,15 +344,13 @@ void KateMainWindow::setupActions()
   connect(documentOpenWith->menu(), SIGNAL(aboutToShow()), this, SLOT(mSlotFixOpenWithMenu()));
   connect(documentOpenWith->menu(), SIGNAL(triggered(QAction*)), this, SLOT(slotOpenWithMenuAction(QAction*)));
 
-  a = actionCollection()->addAction(KStandardAction::KeyBindings, this, SLOT(editKeys()));
+  a = KStandardAction::keyBindings(this, SLOT(editKeys()), actionCollection());
   a->setWhatsThis(i18n("Configure the application's keyboard shortcut assignments."));
 
-  a = actionCollection()->addAction(KStandardAction::ConfigureToolbars, "set_configure_toolbars",
-                                    this, SLOT(slotEditToolbars()));
+  a = KStandardAction::configureToolbars(this, SLOT(slotEditToolbars()), actionCollection());
   a->setWhatsThis(i18n("Configure which items should appear in the toolbar(s)."));
 
-  QAction* settingsConfigure = actionCollection()->addAction(KStandardAction::Preferences, "settings_configure",
-                               this, SLOT(slotConfigure()));
+  QAction* settingsConfigure = KStandardAction::preferences(this, SLOT(slotConfigure()), actionCollection());
   settingsConfigure->setWhatsThis(i18n("Configure various aspects of this application and the editing component."));
 
   // tip of the day :-)
@@ -399,7 +396,7 @@ void KateMainWindow::setupActions()
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAs() ) );
   a = actionCollection()->addAction( "sessions_save_default" );
   a->setIcon( KIcon("document-save-as") );
-  a->setText( i18n("Save As &Default...") );
+  a->setText( i18n("Save as &Default...") );
   connect( a, SIGNAL( triggered() ), KateSessionManager::self(), SLOT( sessionSaveAsDefault() ) );
   a = actionCollection()->addAction( "sessions_manage" );
   a->setIcon( KIcon("view-choose") );
@@ -511,6 +508,12 @@ void KateMainWindow::slotNewToolbarConfig()
 }
 
 void KateMainWindow::slotFileQuit()
+{
+  // delay real shutdown outside of this, as we are inside menu action handling
+  QTimer::singleShot(0, this, SLOT(slotFileQuitDelayed()));
+}
+
+void KateMainWindow::slotFileQuitDelayed()
 {
   KateApp::self()->shutdownKate (this);
 }
@@ -797,7 +800,7 @@ void KateMainWindow::slotOpenWithMenuAction(QAction* a)
   }
   else
   {
-    KMessageBox::error(this, i18n("Application '%1' not found!", openWith), i18n("Application not found!"));
+    KMessageBox::error(this, i18n("Application '%1' not found.", openWith), i18n("Application not found"));
   }
 }
 
