@@ -38,6 +38,7 @@
 #include <KActionCollection>
 #include <KIO/NetAccess>
 #include <KIO/CopyJob>
+#include <KStringHandler>
 
 #include <QDir>
 #include <QLabel>
@@ -50,10 +51,9 @@
 #include <unistd.h>
 #include <time.h>
 
-// used to sort the session list (qSort)
-bool caseInsensitiveLessThan(const KateSession::Ptr& a, const KateSession::Ptr& b)
-{
-  return a->sessionName().toLower() < b->sessionName().toLower();
+
+bool katesessions_compare_sessions_ptr(const KateSession::Ptr &s1, const KateSession::Ptr &s2) {
+    return KStringHandler::naturalCompare(s1->sessionName(),s2->sessionName())==-1;
 }
 
 //BEGIN KateSession
@@ -120,7 +120,7 @@ bool KateSession::create (const QString &name, bool force)
 
   // create the file, write name to it!
   KConfig config (sessionFile (), KConfig::SimpleConfig);
-  config.group("General").writeEntry ("Name", m_sessionName);
+//  config.group("General").writeEntry ("Name", m_sessionName);
   config.sync ();
 
   // reinit ourselfs ;)
@@ -143,14 +143,21 @@ bool KateSession::rename (const QString &name)
     m_sessionFileRel = oldRel;
     return false;
   }
-  KIO::CopyJob *job = KIO::move(KUrl(QString("file://") + oldSessionFile), KUrl(QString("file://") + sessionFile()), KIO::HideProgressInfo);
+  KUrl srcUrl(QString("file://"));
+  srcUrl.addPath(oldSessionFile);
+  KUrl destUrl(QString("file://"));
+  destUrl.addPath(sessionFile());
+  KIO::CopyJob *job = KIO::move(srcUrl, destUrl, KIO::HideProgressInfo);
   if ( ! KIO::NetAccess::synchronousRun(job, 0) )
   {
     m_sessionFileRel = oldRel;
     return false;
   }
   m_sessionName = name;
-
+  delete m_writeConfig;
+  m_writeConfig=0;
+  delete m_readConfig;
+  m_readConfig=0;
   return true;
 }
 
@@ -174,7 +181,7 @@ KConfig *KateSession::configWrite ()
     return m_writeConfig;
 
   m_writeConfig = new KConfig (sessionFile (), KConfig::SimpleConfig);
-  m_writeConfig->group("General").writeEntry ("Name", m_sessionName);
+//  m_writeConfig->group("General").writeEntry ("Name", m_sessionName);
 
   return m_writeConfig;
 }
@@ -187,8 +194,8 @@ void KateSession::makeAnonymous()
   delete m_writeConfig;
   m_writeConfig = 0;
 
-  m_sessionFileRel = QString();
-  m_sessionName = QString();
+  m_sessionFileRel.clear();
+  m_sessionName.clear();
 }
 
 //END KateSession
@@ -236,12 +243,18 @@ void KateSessionManager::updateSessionList ()
   for (unsigned int i = 0; i < dir.count(); ++i)
   {
     KateSession *session = new KateSession (this, dir[i]);
+    if (m_activeSession)
+      if (session->sessionName()==m_activeSession->sessionName())
+      {
+        delete session;
+        session=m_activeSession.data();
+      }
     m_sessionList.append (KateSession::Ptr(session));
 
-    kDebug () << "FOUND SESSION: " << session->sessionName() << " FILE: " << session->sessionFile() << " dir[i];" << dir[i];
+    //kDebug () << "FOUND SESSION: " << session->sessionName() << " FILE: " << session->sessionFile() << " dir[i];" << dir[i];
   }
 
-  qSort(m_sessionList.begin(), m_sessionList.end(), caseInsensitiveLessThan);
+  qSort(m_sessionList.begin(), m_sessionList.end(), katesessions_compare_sessions_ptr);
 }
 
 void KateSessionManager::activateSession (KateSession::Ptr session,
@@ -422,7 +435,6 @@ bool KateSessionManager::saveActiveSession (bool tryAsk, bool rememberAsLast)
     c->group("General").writeEntry ("Last Session", activeSession()->sessionFileRelative());
     c->sync ();
   }
-
   return true;
 }
 
@@ -444,6 +456,7 @@ bool KateSessionManager::chooseSession ()
     QFile::copy(defaultSessionFile(), sessionsDir() + "/default.katesession");
     KateSession *ds = new KateSession(this, "default.katesession");
     ds->rename(i18n("Default Session"));
+    lastSession=ds->sessionFileRelative();
     delete ds;
   }
 
@@ -579,6 +592,7 @@ void KateSessionManager::sessionSaveAs ()
 {
   newSessionName();
   saveActiveSession ();
+  emit sessionChanged();
 }
 
 bool KateSessionManager::newSessionName()
@@ -611,7 +625,7 @@ void KateSessionManager::sessionSaveAsDefault ()
 
   // use this local file to store the defaults to
   KConfig defaultConfig(localSessionFile, KConfig::SimpleConfig);
-  defaultConfig.group("General").writeEntry ("Name", QString());
+//  defaultConfig.group("General").writeEntry ("Name", QString());
 
   saveSessionTo(&defaultConfig);
 
@@ -660,25 +674,12 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
 
   //showButtonSeparator(true);
   QFrame *page = new QFrame (this);
-  QHBoxLayout *tll = new QHBoxLayout(page);
+  QVBoxLayout *tll = new QVBoxLayout(page);
   page->setMinimumSize (400, 200);
   setMainWidget(page);
 
-  QHBoxLayout *hb = new QHBoxLayout ();
-  hb->setSpacing (KDialog::spacingHint());
-  tll->addItem(hb);
-
-  QLabel *label = new QLabel (page);
-  hb->addWidget(label);
-  label->setPixmap (UserIcon("sessionchooser"));
-  label->setFrameStyle (QFrame::Panel | QFrame::Sunken);
-  label->setAlignment(Qt::AlignTop);
-  QVBoxLayout *vb = new QVBoxLayout ();
-  vb->setSpacing (KDialog::spacingHint());
-  tll->addItem(vb);
-
   m_sessions = new QTreeWidget (page);
-  vb->addWidget(m_sessions);
+  tll->addWidget(m_sessions);
   QStringList header;
   header << i18n("Session Name");
   header << i18nc("The number of open documents", "Open Documents");
@@ -697,10 +698,12 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
   connect(a, SIGNAL(triggered()), this, SLOT(slotCopySession()));
 
   KateSessionList &slist (KateSessionManager::self()->sessionList());
+  kDebug()<<"Last session is:"<<lastSession;
   for (int i = 0; i < slist.count(); ++i)
   {
     KateSessionChooserItem *item = new KateSessionChooserItem (m_sessions, slist[i]);
 
+    kDebug()<<"Session added to chooser:"<<slist[i]->sessionName()<<"........"<<slist[i]->sessionFileRelative();
     if (slist[i]->sessionFileRelative() == lastSession)
       m_sessions->setCurrentItem (item);
   }
@@ -708,7 +711,7 @@ KateSessionChooser::KateSessionChooser (QWidget *parent, const QString &lastSess
   m_sessions->resizeColumnToContents(0);
 
   m_useLast = new QCheckBox (i18n ("&Always use this choice"), page);
-  vb->addWidget(m_useLast);
+  tll->addWidget(m_useLast);
 
   setResult (resultNone);
 
@@ -913,7 +916,7 @@ void KateSessionManageDialog::selectionChanged (QTreeWidgetItem *current, QTreeW
   const bool validItem = (current != NULL);
 
   m_rename->setEnabled (validItem);
-  m_del->setEnabled (validItem);
+  m_del->setEnabled (validItem && ((KateSessionChooserItem*)current)->session!=KateSessionManager::self()->activeSession());
   button(User2)->setEnabled (validItem);
 }
 
@@ -936,8 +939,12 @@ void KateSessionManageDialog::rename ()
     return;
   }
 
-  if (item->session->rename (name))
+  if (item->session->rename (name)) {
+    if (item->session==KateSessionManager::self()->activeSession()) {
+      emit KateSessionManager::self()->sessionChanged();
+    }
     updateSessionList ();
+  }
   else
     KMessageBox::sorry(this, i18n("The session could not be renamed to \"%1\", there already exists another session with the same name", name), i18n("Session Renaming"));
 }
