@@ -242,9 +242,7 @@ void KateBuildView::slotItemSelected(QTreeWidgetItem *item)
     const int column = item->data(2, Qt::UserRole).toInt();
 
     // open file (if needed, otherwise, this will activate only the right view...)
-    KUrl fileURL;
-    fileURL.setPath( filename );
-    m_win->openUrl( fileURL );
+    m_win->openUrl(KUrl(filename));
 
     // any view active?
     if (!m_win->activeView()) {
@@ -364,7 +362,7 @@ bool KateBuildView::startProcess(const QString &command)
     buildUi.ktabwidget->setCurrentIndex(1);
 
     // set working directory
-    m_proc->setWorkingDirectory(m_make_dir.path(KUrl::AddTrailingSlash));
+    m_proc->setWorkingDirectory(m_make_dir.toLocalFile(KUrl::AddTrailingSlash));
     m_proc->setShellCommand(command);
     m_proc->setOutputChannelMode(KProcess::SeparateChannels);
     m_proc->start();
@@ -514,8 +512,8 @@ void KateBuildView::processLine(const QString &line)
 
     //kDebug() << "File Name:"<<filename<< " msg:"<< msg;
     //add path to file
-    if (QFile::exists(m_make_dir.path(KUrl::AddTrailingSlash)+filename)) {
-        filename = m_make_dir.path(KUrl::AddTrailingSlash)+filename;
+    if (QFile::exists(m_make_dir.toLocalFile(KUrl::AddTrailingSlash)+filename)) {
+        filename = m_make_dir.toLocalFile(KUrl::AddTrailingSlash)+filename;
     }
 
     // Now we have the data we need show the error/warning
