@@ -20,6 +20,7 @@
 */
 #include "bugdetails.h"
 
+#include <QLatin1String>
 #include <QStringList>
 #include <QRegExp>
 #include <kdebug.h>
@@ -129,7 +130,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments() const
     if ( !m_impl )
         return lst;
     BugDetailsPart::List parts = m_impl->parts;
-    for ( BugDetailsPart::List::ConstIterator it = parts.begin(); it != parts.end(); ++it ) {
+    for ( BugDetailsPart::List::ConstIterator it = parts.constBegin(); it != parts.constEnd(); ++it ) {
         lst += extractAttachments( (*it).text );
     }
     return lst;
@@ -140,26 +141,26 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments() const
 QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& text )
 {
     QList<BugDetails::Attachment> lst;
-    QStringList lines = text.split( '\n' );
+    const QStringList lines = text.split( '\n' );
 #ifdef DEBUG_EXTRACT
     kDebug() << lines.count() << " lines.";
 #endif
     QString boundary;
-    for ( QStringList::Iterator it = lines.begin() ; it != lines.end() ; ++it )
+    for ( QStringList::const_iterator it = lines.constBegin() ; it != lines.constEnd() ; ++it )
     {
 #ifdef DEBUG_EXTRACT
         kDebug() << "Line: " << *it;
 #endif
-        if ( (*it).startsWith( " Content-Type" ) ) // ## leading space comes from khtml
+        if ( (*it).startsWith( QLatin1String( " Content-Type" ) ) ) // ## leading space comes from khtml
         {
 #ifdef DEBUG_EXTRACT
             //kDebug() << "BugDetails::extractAttachments going back, looking for empty or boundary=" << boundary;
 #endif
             // Rewind until last empty line
-            QStringList::Iterator rit = it;
-            for ( ; rit != lines.begin() ; --rit ) {
+            QStringList::const_iterator rit = it;
+            for ( ; rit != lines.constBegin() ; --rit ) {
                 QString line = *rit;
-                if ( line.endsWith( "<br />" ) )
+                if ( line.endsWith( QLatin1String( "<br />" ) ) )
                     line = line.left( line.length() - 6 );
                 while ( !line.isEmpty() && line[0] == ' ' )
                     line.remove( 0, 1 );
@@ -169,7 +170,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
                 if ( line.isEmpty() ) {
                     ++rit; // boundary is next line
                     boundary = *rit;
-                    if ( boundary.endsWith( "<br />" ) )
+                    if ( boundary.endsWith( QLatin1String( "<br />" ) ) )
                         boundary = boundary.left( boundary.length() - 6 );
                     if ( boundary[0] == ' ' )
                         boundary.remove( 0, 1 );
@@ -185,7 +186,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
             rit = it;
             for ( ; rit != lines.end() ; ++rit ) {
                 QString header = *rit;
-                if ( header.endsWith( "<br />" ) )
+                if ( header.endsWith( QLatin1String( "<br />" ) ) )
                     header = header.left( header.length() - 6 );
                 if ( header[0] == ' ' )
                     header.remove( 0, 1 );
@@ -194,7 +195,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
 #endif
                 if ( header.isEmpty() )
                     break;
-                if ( header.startsWith( "Content-Disposition:" ) )
+                if ( header.startsWith( QLatin1String( "Content-Disposition:" ) ) )
                 {
 #ifdef DEBUG_EXTRACT
                     kDebug() << "BugDetails::extractAttachments found header " << *rit;
@@ -205,7 +206,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
                     if(pos>-1) {
                         pos+=9;
                         fn=header.mid(pos, header.length()-pos);
-                        if ( fn.startsWith( "\"" ) && fn.endsWith( "\"" ) )
+                        if ( fn.startsWith( '\"' ) && fn.endsWith( '\"' ) )
                             fn = fn.mid( 1, fn.length() - 2 );
                         //filename=decodeRFC2047String(fn, &e_ncCS, defaultCS(), forceCS());
                         filename = fn; // hack
@@ -213,7 +214,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
                     }
 
                 }
-                else if ( header.startsWith( "Content-Transfer-Encoding:" ) )
+                else if ( header.startsWith( QLatin1String( "Content-Transfer-Encoding:" ) ) )
                 {
                     encoding = header.mid( 26 ).toLower();
                     while ( encoding[0] == ' ' )
@@ -235,9 +236,9 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
                 for ( ; it != lines.end() ; ++it )
                 {
                     QString line = *it;
-                    if ( line.endsWith( "</tt>" ) )
+                    if ( line.endsWith( QLatin1String( "</tt>" ) ) )
                         line = line.left( line.length() - 5 );
-                    if ( line.endsWith( "<br />" ) ) // necessary for the boundary check
+                    if ( line.endsWith( QLatin1String( "<br />" ) ) )// necessary for the boundary check
                         line = line.left( line.length() - 6 );
                     while ( !line.isEmpty() && line[0] == ' ' )
                         line.remove( 0, 1 );
@@ -250,7 +251,7 @@ QList<BugDetails::Attachment> BugDetails::extractAttachments( const QString& tex
                     }
                     contents += line; // no newline, because of linebreaking between <br and />
                 }
-                contents = contents.replace( QRegExp("<br */>"), QString() );
+                contents = contents.remove( QRegExp("<br */>") );
 #ifdef DEBUG_EXTRACT
                 kDebug() << "BugDetails::extractAttachments contents=***\n" << contents << "\n***";
 #endif
