@@ -30,6 +30,7 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 
+#include "kdeconfig.h"
 #include "toplevel.h"
 #include "tracedata.h"
 #include "loader.h"
@@ -58,6 +59,9 @@ int main( int argc, char ** argv )
   TopLevel* t;
   Loader::initLoaders();
 
+  KConfig* kc = KGlobal::config().data();
+  ConfigStorage::setStorage(new KDEConfigStorage(kc));
+
   if (a.isSessionRestored()){
     int n = 1;
     while (KMainWindow::canBeRestored(n)){
@@ -87,7 +91,7 @@ int main( int argc, char ** argv )
 
   // to make leak checking in valgrind happy...
   Loader::deleteLoaders();
-  TraceItem::cleanup();
+  ProfileContext::cleanup();
 
   return res;
 }
