@@ -21,18 +21,23 @@
 
 #include <QtGui/QLayout>
 #include <QtGui/QWidget>
+#include <QPainter>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QPrintPreviewDialog>
 
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kapplication.h>
+#include <kcomponentdata.h>
 #include <kdebug.h>
+#include <kdeprintdialog.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandardaction.h>
 #include <kstandarddirs.h>
 #include <kstandardshortcut.h>
-#include <kcomponentdata.h>
 #include <ktemporaryfile.h>
 #include <kparts/genericfactory.h>
 #include <ktempdir.h>
@@ -82,6 +87,7 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringL
 
 	// This creates the "Model creator" and connects the signals and slots
 	m_modelList = new Diff2::KompareModelList( m_diffSettings, m_splitter, this, "komparemodellist" );
+
 	connect( m_modelList, SIGNAL(status( Kompare::Status )),
 	         this, SLOT(slotSetStatus( Kompare::Status )) );
 	connect( m_modelList, SIGNAL(setStatusBarModelInfo( int, int, int, int, int )),
@@ -96,9 +102,7 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringL
 	         this, SIGNAL(appliedChanged()) );
 	connect( m_modelList, SIGNAL(applyDifference( bool )),
 	         this, SIGNAL(appliedChanged()) );
-
-	connect( m_modelList, SIGNAL( setModified( bool ) ),
-	         this, SLOT( slotSetModified( bool ) ) );
+	connect( m_modelList, SIGNAL(updateActions()), this, SLOT(updateActions()) );
 
 	// This is the stuff to connect the "interface" of the kompare part to the model inside
 	connect( m_modelList, SIGNAL(modelsChanged(const Diff2::DiffModelList*)),
@@ -171,7 +175,7 @@ void KomparePart::setupActions()
 	m_saveAll->setIcon(KIcon("document-save-all"));
 	m_saveAll->setText(i18n("Save &All"));
 	m_saveDiff = actionCollection()->addAction("file_save_diff", this, SLOT(saveDiff()));
-	m_saveDiff->setText(i18n("Save .&diff..."));
+	m_saveDiff->setText(i18n("Save &Diff..."));
 	m_swap = actionCollection()->addAction("file_swap", this, SLOT(slotSwap()));
 	m_swap->setText(i18n("Swap Source with Destination"));
 	m_diffStats = actionCollection()->addAction("file_diffstats", this, SLOT(slotShowDiffstats()));
@@ -181,21 +185,25 @@ void KomparePart::setupActions()
 	m_diffRefresh->setText(i18n("Refresh Diff"));
 	m_diffRefresh->setShortcut(KStandardShortcut::reload());
 
+	m_print        = actionCollection()->addAction(KStandardAction::Print, this, SLOT( slotFilePrint() ));
+	m_printPreview = actionCollection()->addAction(KStandardAction::PrintPreview, this, SLOT( slotFilePrintPreview() ));
 	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 }
 
 void KomparePart::updateActions()
 {
-	m_saveAll->setEnabled  ( m_modelList->isModified() );
-	m_saveDiff->setEnabled ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
-	m_swap->setEnabled     ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
-	m_diffRefresh->setEnabled( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
-	m_diffStats->setEnabled( m_modelList->modelCount() > 0 );
+	m_saveAll->setEnabled     ( m_modelList->hasUnsavedChanges() );
+	m_saveDiff->setEnabled    ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
+	m_swap->setEnabled        ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
+	m_diffRefresh->setEnabled ( m_modelList->mode() == Kompare::ComparingFiles || m_modelList->mode() == Kompare::ComparingDirs );
+	m_diffStats->setEnabled   ( m_modelList->modelCount() > 0 );
+	m_print->setEnabled       ( m_modelList->modelCount() > 0 ); // If modellist has models then we have something to print, it's that simple.
+	m_printPreview->setEnabled( m_modelList );
 }
 
 void KomparePart::setEncoding( const QString& encoding )
 {
-	kDebug() << "Encoding: " << encoding << endl;
+	kDebug(8103) << "Encoding: " << encoding << endl;
 	m_modelList->setEncoding( encoding );
 }
 
@@ -328,8 +336,8 @@ bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 	else
 	{
 		// is Local already, check if exists
-		if ( exists( url.path() ) )
-			tempFileName = url.path();
+		if ( exists( url.toLocalFile() ) )
+			tempFileName = url.toLocalFile();
 		else
 		{
 			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>", url.prettyUrl() ) );
@@ -570,11 +578,58 @@ void KomparePart::saveDiff()
 	}
 }
 
+void KomparePart::slotFilePrint()
+{
+	QPrinter printer;
+	printer.setOrientation( QPrinter::Landscape );
+	QPrintDialog* dlg = KdePrint::createPrintDialog( &printer, m_splitter );
+
+	if ( dlg->exec() == QDialog::Accepted )
+	{
+		// do some printing in qprinter
+		slotPaintRequested( &printer );
+	}
+
+	delete dlg;
+}
+
+void KomparePart::slotFilePrintPreview()
+{
+	QPrinter printer;
+	printer.setOrientation( QPrinter::Landscape );
+	QPrintPreviewDialog dlg( &printer );
+
+	connect( &dlg, SIGNAL(paintRequested(QPrinter*)), this, SLOT(slotPaintRequested(QPrinter*)) );
+
+	dlg.exec();
+}
+
+void KomparePart::slotPaintRequested( QPrinter* printer )
+{
+	kDebug(8103) << "Now paint something..." << endl;
+	QPainter p;
+	p.begin( printer );
+
+	QSize widgetWidth = m_splitter->parentWidget()->size();
+	kDebug(8103) << "printer.width()     = " << printer->width() << endl;
+	kDebug(8103) << "widgetWidth.width() = " << widgetWidth.width() << endl;
+	qreal factor = ((qreal)printer->width())/((qreal)widgetWidth.width());
+
+	kDebug(8103) << "factor              = " << factor << endl;
+
+	p.scale( factor, factor );
+	m_splitter->parentWidget()->render( &p );
+
+	p.end();
+	kDebug(8103) << "Done painting something..." << endl;
+}
+
 KAboutData* KomparePart::createAboutData()
 {
     KAboutData *about = new KAboutData("kompare", 0, ki18n("KomparePart"), "4.0");
     about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
     about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
+    about->addAuthor(ki18n("Kevin Kofler"), ki18n("Author"), "kevin.kofler@chello.at" );
     return about;
 }
 
@@ -672,7 +727,7 @@ void KomparePart::slotShowError( QString error )
 
 void KomparePart::slotSwap()
 {
-	if ( isModified() )
+	if ( m_modelList->hasUnsavedChanges() )
 	{
 		int query = KMessageBox::warningYesNoCancel
 		            (
@@ -703,7 +758,7 @@ void KomparePart::slotSwap()
 
 void KomparePart::slotRefreshDiff()
 {
-	if ( isModified() )
+	if ( m_modelList->hasUnsavedChanges() )
 	{
 		int query = KMessageBox::warningYesNoCancel
 		            (
@@ -818,7 +873,7 @@ void KomparePart::slotShowDiffstats( void )
 
 bool KomparePart::queryClose()
 {
-	if( !isModified() ) return true;
+	if ( !m_modelList->hasUnsavedChanges() ) return true;
 
 	int query = KMessageBox::warningYesNoCancel
 	            (
@@ -865,14 +920,6 @@ void KomparePart::optionsPreferences()
 		emit configChanged();
 }
 
-void KomparePart::slotSetModified( bool modified )
-{ 
-	kDebug() << "KomparePart::slotSetModified( " << modified << " );" << endl;
-	setModified( modified );
-	updateActions();
-	updateCaption();
-}
-
 #include "kompare_part.moc"
 
 K_EXPORT_PLUGIN( KomparePartFactory )
