@@ -27,6 +27,7 @@
 
 #include "kompareinterface.h"
 
+class QPrinter;
 class QWidget;
 
 class KTemporaryFile;
@@ -80,7 +81,6 @@ public:
 	// use the readProperties and saveProperties methods
 	virtual bool queryClose();
 
-	// bool isModified() const { return m_modelList->isModified(); }
 	// Do we really want to expose this ???
 	const Diff2::KompareModelList* model() const { return m_modelList; };
 
@@ -156,8 +156,9 @@ public slots:
 	/** Save the results of a comparison as a diff file. */
 	void saveDiff();
 
-	/** This slot is connected to the setModifed( bool ) signal from the KompareModelList */
-	void slotSetModified( bool modified );
+	/** To enable printing, the part has the only interesting printable content so putting it here */
+	void slotFilePrint();
+	void slotFilePrintPreview();
 
 signals:
 	void appliedChanged();
@@ -174,6 +175,7 @@ protected:
 	 * return true when everything went ok, false if there were problems
 	 */
 	virtual bool openFile();
+	// ... Uhm we return true without saving ???
 	virtual bool saveFile() { return true; };
 
 	// patchFile
@@ -188,10 +190,13 @@ protected slots:
 	void slotShowDiffstats();
 	void slotRefreshDiff();
 	void optionsPreferences();
+
 	void updateActions();
 	void updateCaption();
 	void updateStatus();
 
+	void slotPaintRequested( QPrinter* );
+
 private:
 	void cleanUpTemporaryFiles();
 	void setupActions();
@@ -217,6 +222,8 @@ private:
 	KAction*                 m_swap;
 	KAction*                 m_diffStats;
 	KAction*                 m_diffRefresh;
+	KAction*                 m_print;
+	KAction*                 m_printPreview;
 
 	KTemporaryFile*          m_tempDiff;
 
