@@ -34,21 +34,28 @@
 
 **************************************************************************** */
 
-#ifndef CatalogPrivate_H
-#define CatalogPrivate_H
+#ifndef CATALOGPRIVATE_H
+#define CATALOGPRIVATE_H
+
+#include "catalogitem.h"
+#include "projectlocal.h"
+#include "state.h"
+#include "pos.h"
 
 #include <kurl.h>
+#include <kautosavefile.h>
+
 #include <QList>
+#include <QLinkedList>
 #include <QStringList>
 #include <QVector>
 #include <QMap>
-
-// #include "msgfmt.h"
-#include "catalogitem.h"
-// #include "regexpextractor.h"
-// #include "kbabel_export.h"
+#include <QSet>
+#include <QTimer>
 
 class QTextCodec;
+class CatalogStorage;
+class Catalog;
 
 class CatalogPrivate
 {
@@ -70,33 +77,52 @@ public:
     QString _langCode;
     QString _emptyStr;
 
-    int _numberOfPluralForms:8;
+    int _numberOfPluralForms;
 
-    bool _readOnly:8;
+    QTimer _autoSaveTimer;
+    KAutoSaveFile* _autoSave;
+    bool _autoSaveDirty;
+    bool _autoSaveRecovered;
 
+    bool _readOnly;
     //for wrapping
-    short _maxLineLength:16;
+    short _maxLineLength;
 
-    QList<int> _fuzzyIndex;
-    QList<int> _untransIndex;
-    QList<int> _errorIndex;
+    QLinkedList<int> _nonApprovedIndex;
+    QLinkedList<int> _emptyIndex;
+    QLinkedList<int> _errorIndex;
 
-    QList<int> _bookmarkIndex;
+    QLinkedList<int> _bookmarkIndex;
 
+    QVector< QLinkedList<int> > _statesIndex;
+
+
+    QLinkedList<Catalog*> _altTransCatalogs;
 
     //for undo/redo
     //keeps pos of the entry that was last modified
     DocPosition _lastModifiedPos;
 
-    QList<int> _modifiedEntries;//just for the nice gui
+    QSet<DocPos> _modifiedEntries;//just for the nice gui
 
-    explicit CatalogPrivate()
+    QString _phase;
+    ProjectLocal::PersonRole _phaseRole;
+
+    explicit CatalogPrivate(QObject* parent)
            : _mimeTypes( "text/plain" )
            , fileCodec(0)
            , _numberOfPluralForms(-1)
+           , _autoSave(new KAutoSaveFile(parent))
+           , _autoSaveDirty(true)
+           , _autoSaveRecovered(false)
            , _readOnly(false)
+           , _phaseRole(ProjectLocal::Undefined)
     {
+        _statesIndex.resize(StateCount);
     }
+
+    bool addToEmptyIndexIfAppropriate(CatalogStorage*, const DocPosition& pos);
+    bool removeFromUntransIndexIfAppropriate(CatalogStorage*, const DocPosition& pos);
 };
 
 
