@@ -1,5 +1,5 @@
 /*
-Copyright 2008 Nick Shaforostoff <shaforostoff@kde.ru>
+Copyright 2008-2009 Nick Shaforostoff <shaforostoff@kde.ru>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -23,11 +23,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define CATALOGSTORAGE_H
 
 #include "pos.h"
-#include "tagrange.h"
+#include "catalogstring.h"
+#include "note.h"
+#include "state.h"
+#include "phase.h"
+#include "alttrans.h"
+#include "catalogcapabilities.h"
 
 #include <kurl.h>
 #include <QStringList>
 
+
 /**
  * Abstract interface for storage of translation file
  *
@@ -41,14 +47,13 @@ public:
     CatalogStorage();
     virtual ~CatalogStorage();
 
-    virtual bool load(const KUrl& url)=0;
-    virtual bool save(const KUrl& url=KUrl())=0;
+    virtual int capabilities() const=0;
+
+    virtual int load(QIODevice* device)=0;
+    virtual bool save(QIODevice* device)=0;
 
     virtual int size() const=0;
     int numberOfEntries()const{return size();}
-    virtual void clear()=0;//TODO remove this
-    virtual bool isEmpty() const=0;//TODO remove this
-
     int numberOfPluralForms() const{return m_numberOfPluralForms;}
 
     /**
@@ -58,31 +63,42 @@ public:
     **/
     virtual QString source(const DocPosition& pos) const=0;
     virtual QString target(const DocPosition& pos) const=0;
-    virtual CatalogString sourceWithTags(const DocPosition& pos) const=0;
-    virtual CatalogString targetWithTags(const DocPosition& pos) const=0;
+    virtual CatalogString sourceWithTags(DocPosition pos) const=0;
+    virtual CatalogString targetWithTags(DocPosition pos) const=0;
+    virtual CatalogString catalogString(const DocPosition& pos) const=0;
 
     /**
      * edit operations used by undo/redo  system and sync-mode
     **/
     virtual void targetDelete(const DocPosition& pos, int count)=0;
     virtual void targetInsert(const DocPosition& pos, const QString& arg)=0;
-    virtual void setTarget(const DocPosition& pos, const QString& arg)=0;
+    virtual void setTarget(const DocPosition& pos, const QString& arg)=0;//called for mergeCatalog
+    virtual void targetInsertTag(const DocPosition&, const InlineTag&){}
+    virtual InlineTag targetDeleteTag(const DocPosition&){return InlineTag();}
+    virtual Phase updatePhase(const Phase&){return Phase();}
+    virtual QList<Phase> allPhases() const{return QList<Phase>();}
+    virtual QMap<QString,Tool> allTools() const{return QMap<QString,Tool>();}
 
-    /**
-     * all plural forms
-     *
-     * pos.form doesn't matter
-    **/
+    /// all plural forms. pos.form doesn't matter
     virtual QStringList sourceAllForms(const DocPosition& pos) const=0;
     virtual QStringList targetAllForms(const DocPosition& pos) const=0;
 
-    //DocPosition.form - number of <note>
-    virtual QString note(const DocPosition& pos) const=0;
-    virtual int noteCount(const DocPosition& pos) const=0;
+    virtual QVector<AltTrans> altTrans(const DocPosition& pos) const=0;
+    virtual QVector<Note> notes(const DocPosition& pos) const=0;
+    virtual Note setNote(DocPosition pos, const Note& note)=0;
+    virtual QStringList noteAuthors() const{return QStringList();}
+    virtual QVector<Note> developerNotes(const DocPosition& pos) const=0;
+    virtual QStringList sourceFiles(const DocPosition& pos) const=0;
+
+    virtual QString setPhase(const DocPosition& pos, const QString& phase){return QString();}
+    virtual QString phase(const DocPosition& pos) const {return QString();}
+    virtual Phase phase(const QString& name) const{return Phase();}
+    virtual QVector<Note> phaseNotes(const QString& phase) const{return QVector<Note>();}
+    virtual QVector<Note> setPhaseNotes(const QString& phase, QVector<Note> notes){return QVector<Note>();}
 
     //DocPosition.form - number of <context>
-    virtual QString context(const DocPosition& pos) const=0;
-    virtual int contextCount(const DocPosition& pos) const=0;
+    virtual QString context(const DocPosition&) const=0;
+    virtual int contextCount(const DocPosition&) const=0;
 
     /**
      * user-invisible data for matching, e.g. during TM database lookup
@@ -96,27 +112,35 @@ public:
      *
      * pos.form doesn't matter
     **/
-    virtual QStringList matchData(const DocPosition& pos) const=0;
+    virtual QStringList matchData(const DocPosition&) const=0;
 
     /**
      * entry id unique for this file
      *
      * pos.form doesn't matter
     **/
-    virtual QString id(const DocPosition& pos) const=0;
+    virtual QString id(const DocPosition&) const=0;
 
-    virtual bool isPlural(const DocPosition& pos) const=0;
+    virtual bool isPlural(const DocPosition&) const=0;
 
-    virtual bool isUntranslated(const DocPosition& pos) const=0;
+    virtual bool isEmpty(const DocPosition&) const=0;
 
-    virtual bool isApproved(const DocPosition& pos) const=0;
-    virtual void setApproved(const DocPosition& pos, bool approved)=0;
+    virtual bool isEquivTrans(const DocPosition&) const{return true;}
+    virtual void setEquivTrans(const DocPosition&, bool equivTrans){}
 
+    virtual bool isApproved(const DocPosition&) const{return true;}
+    virtual void setApproved(const DocPosition&, bool approved){}
+    virtual TargetState state(const DocPosition&) const{return New;}
+    virtual TargetState setState(const DocPosition&, TargetState){return New;}
+
+
+    virtual int binUnitsCount() const {return 0;}
+    virtual int unitById(const QString& id) const {return 0;}
 
     const KUrl& url() const {return m_url;}
     void setUrl(const KUrl& u){m_url=u;}//TODO
 
-    virtual QString mimetype()const=0;
+    virtual QString mimetype() const=0;
 
 protected:
     KUrl m_url;
