@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2008 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2008-2009 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -23,24 +23,21 @@
 
 #include "lokalizemainwindow.h"
 #include "actionproxy.h"
-#include "kaider.h"
-#include "projectwindow.h"
-#include "tmwindow.h"
+#include "editortab.h"
+#include "projecttab.h"
+#include "tmtab.h"
 #include "prefs_lokalize.h"
 
 #define WEBQUERY_ENABLE
 
-//views
-#include "glossaryview.h"
-#ifdef WEBQUERY_ENABLE
-#include "webqueryview.h"
-#endif
-#include "tmview.h"
-
 #include "project.h"
+#include "projectlocal.h"
 #include "prefs.h"
 
+#include "multieditoradaptor.h"
+
 #include <kglobal.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kicon.h>
 #include <kmenubar.h>
@@ -49,10 +46,6 @@
 #include <kmessagebox.h>
 #include <kapplication.h>
 
-#if QT_VERSION >= 0x040400
-    #include <kfadewidgeteffect.h>
-#endif
-
 
 #include <kio/netaccess.h>
 #include <kaction.h>
@@ -82,7 +75,11 @@ LokalizeMainWindow::LokalizeMainWindow()
  , m_projectSubWindow(0)
  , m_editorActions(new QActionGroup(this))
  , m_managerActions(new QActionGroup(this))
+ , m_spareEditor(new EditorTab(this,false))
+ , m_multiEditorAdaptor(new MultiEditorAdaptor(m_spareEditor))
+ , m_projectScriptingPlugin(0)
 {
+    m_spareEditor->hide();
     m_mdiArea->setViewMode(QMdiArea::TabbedView);
     setCentralWidget(m_mdiArea);
     connect(m_mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)),this,SLOT(slotSubWindowActivated(QMdiSubWindow*)));
@@ -105,29 +102,16 @@ LokalizeMainWindow::LokalizeMainWindow()
 
     setAttribute(Qt::WA_DeleteOnClose,true);
 
-//BEGIN RESTORE STATE
 
-    KConfig config;
-
-    m_openRecentFileAction->loadEntries(KConfigGroup(&config,"RecentFiles"));
-    m_openRecentProjectAction->loadEntries(KConfigGroup(&config,"RecentProjects"));
-
-    KConfigGroup stateGroup(&config,"State");
-
-    QString path;
-    if (Project::instance()->isLoaded())
-        projectLoaded();
-    else
+    if (!qApp->isSessionRestored())
     {
-        path=stateGroup.readEntry("Project",path);
-        Project::instance()->load(path);
-        //if isEmpty()?
+        KConfig config;
+        KConfigGroup stateGroup(&config,"State");
+        readProperties(stateGroup);
     }
+
     registerDBusAdaptor();
 
-//END RESTORE STATE
-
-
     //QTimer::singleShot(0,this,SLOT(initLater()));
 }
 void LokalizeMainWindow::initLater()
@@ -137,16 +121,13 @@ void LokalizeMainWindow::initLater()
 LokalizeMainWindow::~LokalizeMainWindow()
 {
     KConfig config;
-    m_openRecentFileAction->saveEntries(KConfigGroup(&config,"RecentFiles"));
-    m_openRecentProjectAction->saveEntries(KConfigGroup(&config,"RecentProjects"));
-
-
-    saveProjectState();
+    KConfigGroup stateGroup(&config,"State");
+    saveProjectState(stateGroup);
 }
 
 void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
 {
-    QTime aaa;aaa.start();
+    //QTime aaa;aaa.start();
     if (!w || m_prevSubWindow==w)
         return;
 
@@ -157,10 +138,10 @@ void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
         guiFactory()->removeClient( prevEditor->guiClient()   );
         prevEditor->statusBarItems.unregisterStatusBar();
 
-        if (qobject_cast<EditorWindow*>(prevEditor))
+        if (qobject_cast<EditorTab*>(prevEditor))
         {
-            EditorWindow* w=static_cast<EditorWindow*>( prevEditor );
-            KAiderState state=w->state();
+            EditorTab* w=static_cast<EditorTab*>( prevEditor );
+            EditorState state=w->state();
             m_lastEditorState=state.dockWidgets.toBase64();
         }
             /*
@@ -181,14 +162,16 @@ void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
 */
     }
     LokalizeSubwindowBase* editor=static_cast<LokalizeSubwindowBase2*>( w->widget() );
-    if (qobject_cast<EditorWindow*>(editor))
+    if (qobject_cast<EditorTab*>(editor))
     {
-        EditorWindow* w=static_cast<EditorWindow*>( editor );
+        EditorTab* w=static_cast<EditorTab*>( editor );
         w->setProperFocus();
 
-        KAiderState state=w->state();
+        EditorState state=w->state();
         m_lastEditorState=state.dockWidgets.toBase64();
 
+        m_multiEditorAdaptor->setEditorTab(w);
+//         connect(m_multiEditorAdaptor,SIGNAL(srcFileOpenRequested(QString,int)),this,SLOT(showTM()));
 /*
         KMenu* projectActions=static_cast<KMenu*>(factory()->container("project_actions",this));
         QList<QAction*> actionz=projectActions->actions();
@@ -212,7 +195,7 @@ void LokalizeMainWindow::slotSubWindowActivated(QMdiSubWindow* w)
 
     m_prevSubWindow=w;
 
-    kWarning()<<"finished"<<aaa.elapsed();
+    //kWarning()<<"finished"<<aaa.elapsed();
 }
 
 
@@ -223,30 +206,37 @@ bool LokalizeMainWindow::queryClose()
     while (--i>=0)
     {
         //if (editors.at(i)==m_projectSubWindow)
-        if (!qobject_cast<EditorWindow*>(editors.at(i)->widget()))
+        if (!qobject_cast<EditorTab*>(editors.at(i)->widget()))
             continue;
-        if (!  static_cast<EditorWindow*>( editors.at(i)->widget() )->queryClose())
+        if (!  static_cast<EditorTab*>( editors.at(i)->widget() )->queryClose())
             return false;
     }
 
     return true;
 }
 
-EditorWindow* LokalizeMainWindow::fileOpen(KUrl url, int entry/*, int offset*/,bool setAsActive, const QString& mergeFile)
+EditorTab* LokalizeMainWindow::fileOpen(KUrl url, int entry/*, int offset*/,bool setAsActive, const QString& mergeFile)
 {
     if (!url.isEmpty()&&m_fileToEditor.contains(url)&&m_fileToEditor.value(url))
     {
-        m_mdiArea->setActiveSubWindow(m_fileToEditor.value(url));
-        return static_cast<EditorWindow*>(m_fileToEditor.value(url)->widget());
+        kWarning()<<"already opened";
+        QMdiSubWindow* sw=m_fileToEditor.value(url);
+        m_mdiArea->setActiveSubWindow(sw);
+        return static_cast<EditorTab*>(sw->widget());
     }
 
-    EditorWindow* w=new EditorWindow(this);
     QByteArray state=m_lastEditorState;
-
+    EditorTab* w=new EditorTab(this);
     QMdiSubWindow* sw=0;
     if (!url.isEmpty())//create QMdiSubWindow BEFORE fileOpen() because it causes some strange QMdiArea behaviour otherwise
         sw=m_mdiArea->addSubWindow(w);
-    if (!w->fileOpen(url) || m_fileToEditor.contains(w->currentUrl()))
+
+    KUrl baseUrl;
+    QMdiSubWindow* activeSW=m_mdiArea->currentSubWindow();
+    if (activeSW && qobject_cast<LokalizeSubwindowBase*>(activeSW->widget()))
+        baseUrl=static_cast<LokalizeSubwindowBase*>(activeSW->widget())->currentUrl();
+
+    if (!w->fileOpen(url,baseUrl))
     {
         if (sw)
         {
@@ -254,85 +244,96 @@ EditorWindow* LokalizeMainWindow::fileOpen(KUrl url, int entry/*, int offset*/,b
             sw->deleteLater();
         }
         w->deleteLater();
-
-        if (m_fileToEditor.contains(w->currentUrl())&&m_fileToEditor.value(url))
-        {
-            m_mdiArea->setActiveSubWindow(m_fileToEditor.value(w->currentUrl()));
-            return static_cast<EditorWindow*>(m_fileToEditor.value(w->currentUrl())->widget());
-        }
         return 0;
     }
 
-
     if (!sw)
         sw=m_mdiArea->addSubWindow(w);
     w->showMaximized();
     sw->showMaximized();
 
-
-
-//     if (state.isEmpty())
-//     {
-//         QMdiSubWindow* activeSW=m_mdiArea->activeSubWindow();
-//         if (activeSW)
-//             state=static_cast<EditorWindow*>( activeSW->widget() )->saveState().toBase64();
-//     }
     if (!state.isEmpty())
         w->restoreState(QByteArray::fromBase64(state));
 
     if (entry/* || offset*/)
-        w->gotoEntry(DocPosition(entry/*, Msgstr, 0, offset*/));
+        w->gotoEntry(DocPosition(entry/*, DocPosition::Target, 0, offset*/));
     if (setAsActive)
     {
         m_toBeActiveSubWindow=sw;
         QTimer::singleShot(0,this,SLOT(applyToBeActiveSubWindow()));
     }
+
     if (!mergeFile.isEmpty())
         w->mergeOpen(mergeFile);
 
     m_openRecentFileAction->addUrl(w->currentUrl());
-    connect (sw, SIGNAL(destroyed(QObject*)),this,SLOT(editorClosed(QObject*)));
+    connect(sw, SIGNAL(destroyed(QObject*)),this,SLOT(editorClosed(QObject*)));
+    connect(w, SIGNAL(aboutToBeClosed()),this,SLOT(resetMultiEditorAdaptor()));
+    connect(w, SIGNAL(fileOpenRequested(KUrl,QString,QString)),this,SLOT(fileOpen(KUrl,QString,QString)));
+
+    QString fn=url.fileName();
+    FileToEditor::const_iterator i = m_fileToEditor.constBegin();
+    while (i != m_fileToEditor.constEnd())
+    {
+        if (i.key().fileName()==fn)
+        {
+            static_cast<EditorTab*>(i.value()->widget())->setFullPathShown(true);
+            w->setFullPathShown(true);
+        }
+        ++i;
+    }
     m_fileToEditor.insert(w->currentUrl(),sw);
+
     sw->setAttribute(Qt::WA_DeleteOnClose,true);
     emit editorAdded();
     return w;
 }
 
+void LokalizeMainWindow::resetMultiEditorAdaptor()
+{
+    m_multiEditorAdaptor->setEditorTab(m_spareEditor); //it will be reparented shortly if there are other editors
+}
+
 void LokalizeMainWindow::editorClosed(QObject* obj)
 {
-    m_fileToEditor.remove(m_fileToEditor.key(qobject_cast< QMdiSubWindow* >(obj)));
+    m_fileToEditor.remove(m_fileToEditor.key(static_cast<QMdiSubWindow*>(obj)));
 }
 
-void LokalizeMainWindow::fileOpen(const KUrl& url, const QString& source, const QString& ctxt)
+EditorTab* LokalizeMainWindow::fileOpen(const KUrl& url, const QString& source, const QString& ctxt)
 {
-    EditorWindow* w=fileOpen(url);
+    EditorTab* w=fileOpen(url);
     if (!w)
-        return;//TODO message
+        return 0;//TODO message
     w->findEntryBySourceContext(source,ctxt);
+    return w;
 }
 
-void LokalizeMainWindow::showProjectOverview()
+QObject* LokalizeMainWindow::projectOverview()
 {
     if (!m_projectSubWindow)
     {
-        ProjectWindow* w=new ProjectWindow(this);
+        ProjectTab* w=new ProjectTab(this);
         m_projectSubWindow=m_mdiArea->addSubWindow(w);
         w->showMaximized();
         m_projectSubWindow->showMaximized();
         connect(w, SIGNAL(fileOpenRequested(KUrl)),this,SLOT(fileOpen(KUrl)));
-        connect(w, SIGNAL(searchRequested(KUrl::List)),this,SLOT(searchInFiles(KUrl::List)));
-        connect(w, SIGNAL(replaceRequested(KUrl::List)),this,SLOT(replaceInFiles(KUrl::List)));
-        connect(w, SIGNAL(spellcheckRequested(KUrl::List)),this,SLOT(spellcheckFiles(KUrl::List)));
     }
+    if (m_mdiArea->currentSubWindow()==m_projectSubWindow)
+        return m_projectSubWindow->widget();
+    return 0;
+}
 
+void LokalizeMainWindow::showProjectOverview()
+{
+    projectOverview();
     m_mdiArea->setActiveSubWindow(m_projectSubWindow);
 }
 
-TM::TMWindow* LokalizeMainWindow::showTM()
+TM::TMTab* LokalizeMainWindow::showTM()
 {
     if (!m_translationMemorySubWindow)
     {
-        TM::TMWindow* w=new TM::TMWindow(this);
+        TM::TMTab* w=new TM::TMTab(this);
         m_translationMemorySubWindow=m_mdiArea->addSubWindow(w);
         w->showMaximized();
         m_translationMemorySubWindow->showMaximized();
@@ -340,7 +341,7 @@ TM::TMWindow* LokalizeMainWindow::showTM()
     }
 
     m_mdiArea->setActiveSubWindow(m_translationMemorySubWindow);
-    return static_cast<TM::TMWindow*>(m_translationMemorySubWindow->widget());
+    return static_cast<TM::TMTab*>(m_translationMemorySubWindow->widget());
 }
 
 void LokalizeMainWindow::applyToBeActiveSubWindow()
@@ -348,33 +349,6 @@ void LokalizeMainWindow::applyToBeActiveSubWindow()
     m_mdiArea->setActiveSubWindow(m_toBeActiveSubWindow);
 }
 
-void LokalizeMainWindow::searchInFiles(const KUrl::List& urls)
-{
-    EditorWindow* w=new EditorWindow(this);
-    QMdiSubWindow* sw=0;
-    sw=m_mdiArea->addSubWindow(w);
-    w->showMaximized();
-    sw->showMaximized();
-
-    static_cast<EditorWindow*>( m_mdiArea->activeSubWindow()->widget() )->findInFiles(urls);
-/*    EditorWindow* a=new EditorWindow;
-    a->findInFiles(urls);
-    a->show();
-    */
-//    void replaceInFiles(const KUrl::List&);
-}
-void LokalizeMainWindow::replaceInFiles(const KUrl::List&)
-{
-
-}
-void LokalizeMainWindow::spellcheckFiles(const KUrl::List& urls)
-{
-    EditorWindow* a=new EditorWindow(this);
-    a->spellcheckFiles(urls);
-    a->show();
-}
-
-
 
 void LokalizeMainWindow::setupActions()
 {
@@ -474,39 +448,49 @@ void LokalizeMainWindow::setupActions()
     connect(m_openRecentProjectAction,SIGNAL(urlSelected(KUrl)),this,SLOT(openProject(KUrl)));
     connect(Project::instance(),SIGNAL(loaded()), this,SLOT(projectLoaded()));
 
-    action = proj->addAction("project_create",sc,SLOT(projectCreate()));
-    action->setText(i18nc("@action:inmenu","Create new project"));
-
     setupGUI(Default,"lokalizemainwindowui.rc");
 
     kWarning()<<"finished"<<aaa.elapsed();
 }
 
-void LokalizeMainWindow::openProject(const QString& path)
+bool LokalizeMainWindow::closeProject()
 {
-    if (queryClose())
-    {
-        saveProjectState();
-        //close files from previous project
-        QList<QMdiSubWindow*> editors=m_mdiArea->subWindowList();
-        int i=editors.size();
-        while (--i>=0)
-        {
-            if (editors.at(i)==m_translationMemorySubWindow)
-                editors.at(i)->deleteLater();
-            else if (qobject_cast<EditorWindow*>(editors.at(i)->widget()))
-            {
-                m_fileToEditor.remove(static_cast<EditorWindow*>(editors.at(i)->widget())->currentUrl());//safety
-                editors.at(i)->deleteLater();
-            }
-        }
-        //TODO scripts
+    if (!queryClose())
+        return false;
 
-        SettingsController::instance()->projectOpen(path);
+    KConfigGroup emptyGroup; //don't save which project to reopen
+    saveProjectState(emptyGroup);
+    //close files from previous project
+    QList<QMdiSubWindow*> editors=m_mdiArea->subWindowList();
+    int i=editors.size();
+    while (--i>=0)
+    {
+        if (editors.at(i)==m_translationMemorySubWindow)
+            editors.at(i)->deleteLater();
+        else if (qobject_cast<EditorTab*>(editors.at(i)->widget()))
+        {
+            m_fileToEditor.remove(static_cast<EditorTab*>(editors.at(i)->widget())->currentUrl());//safety
+            m_mdiArea->removeSubWindow(editors.at(i));
+            editors.at(i)->deleteLater();
+        }
     }
+    Project::instance()->load(QString());
+    //TODO scripts
+    return true;
 }
 
-void LokalizeMainWindow::saveProjectState()
+void LokalizeMainWindow::openProject(const QString& path)
+{
+    if (closeProject())
+        SettingsController::instance()->projectOpen(path);
+}
+
+void LokalizeMainWindow::saveProperties(KConfigGroup& stateGroup)
+{
+    saveProjectState(stateGroup);
+}
+
+void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
 {
     QList<QMdiSubWindow*> editors=m_mdiArea->subWindowList();
     QStringList files;
@@ -520,11 +504,11 @@ void LokalizeMainWindow::saveProjectState()
     while (--i>=0)
     {
         //if (editors.at(i)==m_projectSubWindow)
-        if (!qobject_cast<EditorWindow*>(editors.at(i)->widget()))
+        if (!qobject_cast<EditorTab*>(editors.at(i)->widget()))
             continue;
         if (editors.at(i)==activeSW)
             activeSWIndex=files.size();
-        KAiderState state=static_cast<EditorWindow*>( editors.at(i)->widget() )->state();
+        EditorState state=static_cast<EditorTab*>( editors.at(i)->widget() )->state();
         files.append(state.url.pathOrUrl());
         mergeFiles.append(state.mergeUrl.pathOrUrl());
         dockWidgets.append(state.dockWidgets.toBase64());
@@ -534,10 +518,11 @@ void LokalizeMainWindow::saveProjectState()
     }
     //if (activeSWIndex==-1 && activeSW==m_projectSubWindow)
 
-    KConfig config;
-    KConfigGroup stateGroup(&config,"State");
-    stateGroup.writeEntry("Project",Project::instance()->path());
+    if (stateGroup.isValid())
+        stateGroup.writeEntry("Project",Project::instance()->path());
 
+
+    KConfig config;
     KConfigGroup projectStateGroup(&config,"State-"+Project::instance()->path());
     projectStateGroup.writeEntry("Active",activeSWIndex);
     projectStateGroup.writeEntry("Files",files);
@@ -545,16 +530,45 @@ void LokalizeMainWindow::saveProjectState()
     projectStateGroup.writeEntry("DockWidgets",dockWidgets);
     //stateGroup.writeEntry("Offsets",offsets);
     projectStateGroup.writeEntry("Entries",entries);
+
+
+    QString nameSpecifier=Project::instance()->path();
+    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
+    KConfig* c=stateGroup.isValid()?stateGroup.config():&config;
+    m_openRecentFileAction->saveEntries(KConfigGroup(c,"RecentFiles"+nameSpecifier));
+
+    m_openRecentProjectAction->saveEntries(KConfigGroup(&config,"RecentProjects"));
+}
+
+void LokalizeMainWindow::readProperties(const KConfigGroup& stateGroup)
+{
+    KConfig config;
+    const KConfig* c=stateGroup.isValid()?stateGroup.config():&config;
+    m_openRecentProjectAction->loadEntries(KConfigGroup(c,"RecentProjects"));
+
+    QString path;
+    if (Project::instance()->isLoaded())
+        projectLoaded();
+    else
+    {
+        path=stateGroup.readEntry("Project",path);
+        Project::instance()->load(path);
+        //if isEmpty()?
+    }
 }
 
 void LokalizeMainWindow::projectLoaded()
 {
     m_openRecentProjectAction->addUrl( KUrl::fromPath(Project::instance()->path()) );
-    setCaption(Project::instance()->projectID());
 
     KConfig config;
 
-    //if project isn't loaded, still restore opened files
+    QString nameSpecifier=Project::instance()->path();
+    if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
+    m_openRecentFileAction->loadEntries(KConfigGroup(&config,"RecentFiles"+nameSpecifier));
+
+
+    //if project isn't loaded, still restore opened files from "State-"
     KConfigGroup projectStateGroup(&config,"State-"+Project::instance()->path());
 
     QStringList files;
@@ -582,35 +596,103 @@ void LokalizeMainWindow::projectLoaded()
         m_toBeActiveSubWindow=m_projectSubWindow;
         QTimer::singleShot(0,this,SLOT(applyToBeActiveSubWindow()));
     }
+
+    setCaption(Project::instance()->projectID());
+
+    QTimer::singleShot(0,this,SLOT(loadProjectScripts()));
 }
 
-void LokalizeMainWindow::restoreState()
-{
-    /*restoreState(m_state);
-    m_state=saveState();*/
-}
-#if 1
+
+
 //BEGIN DBus interface
 
-
-
+//#include "plugin.h"
 #include "mainwindowadaptor.h"
 #include <kross/core/actioncollection.h>
 #include <kross/core/manager.h>
-#include <kross/ui/plugin.h>
 
 using namespace Kross;
 
 class MyScriptingPlugin: public Kross::ScriptingPlugin
 {
 public:
-    MyScriptingPlugin(QObject* parent)
-        : Kross::ScriptingPlugin(parent)
+    MyScriptingPlugin(QObject* lokalize,QObject* editor)
+        : Kross::ScriptingPlugin(lokalize)
     {
-        setXMLFile("translationmemoryrui.rc",true);
+        addObject(lokalize,"Lokalize");
+        addObject(Project::instance(),"Project");
+        addObject(editor,"Editor");
+        setXMLFile("scriptsui.rc",true);
     }
     ~MyScriptingPlugin(){}
 };
+
+#define PROJECTRCFILE "scripts.rc"
+#define PROJECTRCFILEDIR  Project::instance()->projectDir()+"/lokalize-scripts"
+#define PROJECTRCFILEPATH Project::instance()->projectDir()+"/lokalize-scripts" "/" PROJECTRCFILE
+//TODO be lazy creating scripts dir
+ProjectScriptingPlugin::ProjectScriptingPlugin(QObject* lokalize, QObject* editor)
+ : Kross::ScriptingPlugin(Project::instance()->kind(),
+                          PROJECTRCFILEPATH,
+                          Project::instance()->kind(), lokalize)
+{
+    QString filepath=PROJECTRCFILEPATH;
+    if (!QFile::exists(filepath))
+    {
+        KUrl dir = KUrl(filepath).directory();
+        KIO::NetAccess::mkdir(dir, 0);
+        QFile f(filepath);
+        f.open(QIODevice::WriteOnly);
+        QTextStream out(&f);
+        out <<"<!-- see help for the syntax -->";
+        f.close();
+    }
+
+    //kWarning()<<Kross::Manager::self().hasInterpreterInfo("python");
+    addObject(lokalize,"Lokalize",ChildrenInterface::AutoConnectSignals);
+    addObject(Project::instance(),"Project",ChildrenInterface::AutoConnectSignals);
+    addObject(editor,"Editor",ChildrenInterface::AutoConnectSignals);
+    setXMLFile("scriptsui.rc",true);
+}
+
+void ProjectScriptingPlugin::setDOMDocument (const QDomDocument &document, bool merge)
+{
+    Kross::ScriptingPlugin::setDOMDocument(document, merge);
+    QTimer::singleShot(0,this, SLOT(doAutoruns()));
+}
+
+void ProjectScriptingPlugin::doAutoruns()
+{
+    Kross::ActionCollection* collection=Kross::Manager::self().actionCollection()->collection(Project::instance()->kind());
+    if (!collection) return;
+    foreach(const QString &collectionname, collection->collections())
+    {
+        Kross::ActionCollection* c = collection->collection(collectionname);
+        if(!c->isEnabled()) continue;
+
+        foreach(Kross::Action* action, c->actions())
+        {
+            if (action->property("autorun").toBool())
+                action->trigger();
+            if (action->property("first-run").toBool() && Project::local()->firstRun())
+                action->trigger();
+        }
+    }
+}
+
+ProjectScriptingPlugin::~ProjectScriptingPlugin()
+{
+    Kross::ActionCollection* collection=Kross::Manager::self().actionCollection()->collection(Project::instance()->kind());
+    if (!collection) return;
+
+    QString scriptsrc=PROJECTRCFILE;
+    QDir rcdir(PROJECTRCFILEDIR);
+    kWarning()<<rcdir.entryList(QStringList("*.rc"),QDir::Files);
+    foreach(const QString& rc, QDir(PROJECTRCFILEDIR).entryList(QStringList("*.rc"),QDir::Files))
+        if (rc!=scriptsrc)
+            kWarning()<<rc<<collection->readXmlFile(rcdir.absoluteFilePath(rc));
+}
+
 /*
 void LokalizeMainWindow::checkForProjectAlreadyOpened()
 {
@@ -630,37 +712,17 @@ void LokalizeMainWindow::checkForProjectAlreadyOpened()
 
 void LokalizeMainWindow::registerDBusAdaptor()
 {
-    MainWindowAdaptor* adaptor=new MainWindowAdaptor(this);
+    new MainWindowAdaptor(this);
     QDBusConnection::sessionBus().registerObject("/ThisIsWhatYouWant", this);
     QDBusConnection::sessionBus().unregisterObject("/KDebug",QDBusConnection::UnregisterTree);
 
     //kWarning()<<QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
-
 #ifndef Q_WS_MAC
     //TODO really fix!!!
-    MyScriptingPlugin* sp=new MyScriptingPlugin(this);
-    guiFactory()->addClient(  sp );
+    guiFactory()->addClient(new MyScriptingPlugin(this,m_multiEditorAdaptor));
 #endif
 
-    KMenu* projectActions=static_cast<KMenu*>(factory()->container("project_actions",this));
-
-//populateWebQueryActions()
-    QStringList a=Project::instance()->scriptsList();
-    int i=a.size();
-    projectActions->menuAction()->setVisible(i);
-    while(--i>=0)
-    {
-        QUrl url(a.at(i));
-        kWarning()<<"action"<<url;
-        Action* action = new Action(this,url);
-        //action->addObject(adaptor, "Lokalize",ChildrenInterface::AutoConnectSignals);
-        action->addObject(this, "Lokalize",ChildrenInterface::AutoConnectSignals);
-        Manager::self().actionCollection()->addAction(action);
-        //action->trigger();
-        projectActions->addAction(action);
-    }
-
-
+    //KMenu* projectActions=static_cast<KMenu*>(factory()->container("project_actions",this));
 
 /*
     KActionCollection* actionCollection = mWindow->actionCollection();
@@ -669,70 +731,78 @@ void LokalizeMainWindow::registerDBusAdaptor()
 */
 }
 
+void LokalizeMainWindow::loadProjectScripts()
+{
+    if (m_projectScriptingPlugin)
+    {
+        guiFactory()->removeClient(m_projectScriptingPlugin);
+        delete m_projectScriptingPlugin;
+    }
+
+    //a HACK to get new .rc files shown w/o requiring a restart
+    m_projectScriptingPlugin=new ProjectScriptingPlugin(this,m_multiEditorAdaptor);
+    delete m_projectScriptingPlugin;
+    m_projectScriptingPlugin=new ProjectScriptingPlugin(this,m_multiEditorAdaptor);
+    guiFactory()->addClient(m_projectScriptingPlugin);
+}
+
 int LokalizeMainWindow::showTranslationMemory()
 {
     /*activateWindow();
     raise();
     show();*/
-    TM::TMWindow* w=showTM();
+    TM::TMTab* w=showTM();
     return w->dbusId();
 }
 
-QString LokalizeMainWindow::currentProject()
+int LokalizeMainWindow::openFileInEditorAt(const QString& path, const QString& source, const QString& ctxt)
 {
-    return Project::instance()->path();
+    EditorTab* w=fileOpen(KUrl(path),source,ctxt);
+    if (!w) return -1;
+    return w->dbusId();
 }
 
 int LokalizeMainWindow::openFileInEditor(const QString& path)
 {
-    EditorWindow* w=fileOpen(KUrl(path));
-    if (!w)
-        return -1;
-    return w->dbusId();
+    return openFileInEditorAt(path,QString(),QString());
 }
 
 QObject* LokalizeMainWindow::activeEditor()
 {
     QList<QMdiSubWindow*> editors=m_mdiArea->subWindowList();
     QMdiSubWindow* activeSW=m_mdiArea->currentSubWindow();
-    if (activeSW && qobject_cast<EditorWindow*>(activeSW->widget()))
-        return activeSW->widget();
-    return 0;
+    if (!activeSW || !qobject_cast<EditorTab*>(activeSW->widget()))
+        return 0;
+    return activeSW->widget();
 }
 
 QObject* LokalizeMainWindow::editorForFile(const QString& path)
 {
-    if (!m_fileToEditor.contains(KUrl(path)))
-        return 0;
+    if (!m_fileToEditor.contains(KUrl(path))) return 0;
     QMdiSubWindow* w=m_fileToEditor.value(KUrl(path));
-    if (!w)
-        return 0;
-    return static_cast<EditorWindow*>(w->widget());
+    if (!w) return 0;
+    return static_cast<EditorTab*>(w->widget());
 }
 
 int LokalizeMainWindow::editorIndexForFile(const QString& path)
 {
-    EditorWindow* editor=static_cast<EditorWindow*>(editorForFile(path));
-    if (!editor)
-        return -1;
+    EditorTab* editor=static_cast<EditorTab*>(editorForFile(path));
+    if (!editor) return -1;
     return editor->dbusId();
 }
 
 
-#include <unistd.h>
-int LokalizeMainWindow::pid()
-{
-    return getpid();
-}
+QString LokalizeMainWindow::currentProject(){return Project::instance()->path();}
 
-QString LokalizeMainWindow::dbusName()
-{
-    return QString("org.kde.lokalize-%1").arg(pid());
-}
+#include <unistd.h>
+int LokalizeMainWindow::pid(){return getpid();}
+QString LokalizeMainWindow::dbusName(){return QString("org.kde.lokalize-%1").arg(pid());}
+void LokalizeMainWindow::busyCursor(bool busy){busy?QApplication::setOverrideCursor(Qt::WaitCursor):QApplication::restoreOverrideCursor();}
+// void LokalizeMainWindow::processEvents(){QCoreApplication::processEvents();}
 
 //END DBus interface
 
-////BEGIN Kross interface
-////END Kross interface
 
-#endif
+
+#include "lokalizemainwindow.moc"
+#include "lokalizesubwindowbase.moc" //this has to be included somewhere ;)
