@@ -1,53 +1,41 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2002-2009                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #include "cmd_set_stereotype.h"
 
 // app includes
-#include "umlwidgetcontroller.h"
-#include "umlwidget.h"
-#include "umlwidgetlist.h"
-#include "umlnamespace.h"
-#include "uml.h"
-#include "umldoc.h"
-#include "umlview.h"
 #include "umlobject.h"
-#include "classifierwidget.h"
-#include "associationwidget.h"
-#include "messagewidget.h"
 
 #include <klocale.h>
 
 namespace Uml
 {
 
-    CmdSetStereotype::CmdSetStereotype(UMLObject * _UMLObj, const QString& stereo)
-        : st(stereo), UMLObj(_UMLObj)
+    CmdSetStereotype::CmdSetStereotype(UMLObject * obj, const QString& stereo)
+        : m_stereo(stereo), m_umlObject(obj)
     {
-        oldst = _UMLObj->getStereotype();
+        m_oldStereo = obj->getStereotype();
     }
 
     CmdSetStereotype::~CmdSetStereotype()
     {
-
     }
 
     void CmdSetStereotype::redo()
     {
-        UMLObj->setStereotypecmd(st);
+        m_umlObject->setStereotypecmd(m_stereo);
     }
 
     void CmdSetStereotype::undo()
     {
-        UMLObj->setStereotypecmd(oldst);
+        m_umlObject->setStereotypecmd(m_oldStereo);
     }
 
 }
