@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -46,7 +46,7 @@
 #include <QtGui/QGridLayout>
 
 ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
-    : QWidget(parent), m_pObject(o), m_pWidget(0), m_pInstanceWidget(0), m_pUmldoc(d)
+  : QWidget(parent), m_pObject(o), m_pWidget(0), m_pInstanceWidget(0), m_pUmldoc(d)
 {
     int margin = fontMetrics().height();
 
@@ -252,7 +252,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLObject* o)
 }
 
 ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
-    : QWidget(parent), m_pObject(0), m_pWidget(o), m_pInstanceWidget(0), m_pUmldoc(d) 
+  : QWidget(parent), m_pObject(0), m_pWidget(o), m_pInstanceWidget(0), m_pUmldoc(d)
 {
     m_pDeconCB = 0;
     m_pMultiCB = 0;
@@ -272,7 +272,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
     m_pClassNameLE = new KLineEdit(this);
-    m_pClassNameLE->setText(o->getName());
+    m_pClassNameLE->setText(o->name());
     m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
 
     m_pInstanceL = new QLabel(this);
@@ -280,23 +280,23 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
     m_pNameLayout->addWidget(m_pInstanceL, 1, 0);
 
     m_pInstanceLE = new KLineEdit(this);
-    m_pInstanceLE->setText(o->getInstanceName());
+    m_pInstanceLE->setText(o->instanceName());
     m_pNameLayout->addWidget(m_pInstanceLE, 1, 1);
     UMLView *view = UMLApp::app()->getCurrentView();
 
     m_pDrawActorCB = new QCheckBox( i18n( "Draw as actor" ) , this );
-    m_pDrawActorCB->setChecked( o->getDrawAsActor() );
+    m_pDrawActorCB->setChecked( o->drawAsActor() );
     m_pNameLayout->addWidget( m_pDrawActorCB, 2, 0 );
 
     if (view->getType() == Uml::dt_Collaboration) {
         m_pMultiCB = new QCheckBox(i18n("Multiple instance"), this);
-        m_pMultiCB->setChecked(o->getMultipleInstance());
+        m_pMultiCB->setChecked(o->multipleInstance());
         m_pNameLayout->addWidget(m_pMultiCB, 2,1);
         if ( m_pDrawActorCB->isChecked() )
             m_pMultiCB->setEnabled( false );
     } else {  // sequence diagram
         m_pDeconCB = new QCheckBox(i18n("Show destruction"), this);
-        m_pDeconCB->setChecked(o->getShowDestruction());
+        m_pDeconCB->setChecked(o->showDestruction());
         m_pNameLayout->addWidget(m_pDeconCB, 2,1);
     }
     // setup documentation
@@ -308,7 +308,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, ObjectWidget* o)
 
     m_pDoc = new KTextEdit(m_pDocGB);
     m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
-    m_pDoc->setText(o->getDoc());
+    m_pDoc->setText(o->documentation());
     docLayout->addWidget(m_pDoc);
     if (m_pMultiCB) {
         connect( m_pDrawActorCB, SIGNAL( toggled( bool ) ), this, SLOT( slotActorToggled( bool ) ) );
@@ -332,9 +332,9 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pNameLayout->setSpacing(6);
     topLayout->addLayout(m_pNameLayout, 3, 2);
     m_pNameL = new QLabel(this);
-    if (widget->getBaseType() == Uml::wt_Component) {
+    if (widget->baseType() == Uml::wt_Component) {
         m_pNameL->setText(i18n("Component name:"));
-    } else if (widget->getBaseType() == Uml::wt_Node) {
+    } else if (widget->baseType() == Uml::wt_Node) {
         m_pNameL->setText(i18n("Node name:"));
     } else {
         uWarning() << "ClassGenPage called on unknown widget type";
@@ -342,7 +342,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pNameLayout->addWidget(m_pNameL, 0, 0);
 
     m_pClassNameLE = new KLineEdit(this);
-    m_pClassNameLE->setText(widget->getName());
+    m_pClassNameLE->setText(widget->name());
     m_pNameLayout->addWidget(m_pClassNameLE, 0, 1);
 
     m_pStereoTypeL = new QLabel(i18n("Stereotype name:"), this);
@@ -351,7 +351,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pStereoTypeCB = new KComboBox(true, this);
     m_pNameLayout->addWidget(m_pStereoTypeCB, 1, 1);
 
-    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->getUMLObject()->getStereotype() );
+    m_pStereoTypeCB->setItemText( m_pStereoTypeCB->currentIndex(), widget->umlObject()->getStereotype() );
     m_pStereoTypeCB->setCompletionMode( KGlobalSettings::CompletionPopup );
 
     m_pInstanceL = new QLabel(this);
@@ -359,7 +359,7 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
     m_pNameLayout->addWidget(m_pInstanceL, 2, 0);
 
     m_pInstanceLE = new KLineEdit(this);
-    m_pInstanceLE->setText(widget->getInstanceName());
+    m_pInstanceLE->setText(widget->instanceName());
     m_pNameLayout->addWidget(m_pInstanceLE, 2, 1);
 
     //setup documentation
@@ -371,11 +371,11 @@ ClassGenPage::ClassGenPage(UMLDoc* d, QWidget* parent, UMLWidget* widget)
 
     m_pDoc = new KTextEdit(m_pDocGB);
     m_pDoc->setLineWrapMode(QTextEdit::WidgetWidth);
-    m_pDoc->setText(widget->getDoc());
+    m_pDoc->setText(widget->documentation());
     docLayout->addWidget(m_pDoc);
 }
 
-ClassGenPage::~ClassGenPage() 
+ClassGenPage::~ClassGenPage()
 {
 }
 
@@ -403,6 +403,10 @@ void ClassGenPage::insertStereotypesSorted(const QString& type)
     m_pStereoTypeCB->completionObject()->addItem( type );
 }
 
+/**
+ * Will move information from the dialog into the object.
+ * Call when the ok or apply button is pressed.
+ */
 void ClassGenPage::updateObject()
 {
     if (m_pObject) {
@@ -488,8 +492,8 @@ void ClassGenPage::updateObject()
             m_pWidget->setShowDestruction( m_pDeconCB->isChecked() );
         }
         QString name = m_pClassNameLE->text();
-        m_pWidget->setDoc(m_pDoc->toPlainText());
-        UMLObject * o = m_pWidget->getUMLObject();
+        m_pWidget->setDocumentation(m_pDoc->toPlainText());
+        UMLObject * o = m_pWidget->umlObject();
         UMLObject * old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
@@ -501,8 +505,8 @@ void ClassGenPage::updateObject()
     else if (m_pInstanceWidget) {
         m_pInstanceWidget->setInstanceName(m_pInstanceLE->text());
         QString name = m_pClassNameLE->text();
-        m_pInstanceWidget->setDoc(m_pDoc->toPlainText());
-        UMLObject* o = m_pInstanceWidget->getUMLObject();
+        m_pInstanceWidget->setDocumentation(m_pDoc->toPlainText());
+        UMLObject* o = m_pInstanceWidget->umlObject();
         UMLObject* old = m_pUmldoc->findUMLObject(name);
         if (old && o != old) {
             KMessageBox::sorry(this, i18n("The name you have chosen\nis already being used.\nThe name has been reset."),
@@ -514,6 +518,11 @@ void ClassGenPage::updateObject()
     } // end if m_pInstanceWidget
 }
 
+/**
+ * When the draw as actor check box is toggled, the draw
+ * as multi instance need to be enabled/disabled. They
+ * both can't be available at the same time.
+ */
 void ClassGenPage::slotActorToggled( bool state )
 {
     if (m_pMultiCB) {
