@@ -1,21 +1,16 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "folder.h"
-// qt/kde includes
-#include <qfile.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+
 // app includes
 #include "uml.h"
 #include "umldoc.h"
@@ -25,68 +20,131 @@
 #include "object_factory.h"
 #include "model_utils.h"
 
+// kde includes
+#include <kdebug.h>
+#include <klocale.h>
+#include <kmessagebox.h>
+
+// qt includes
+#include <QtCore/QFile>
+
+/**
+ * Sets up a Folder.
+ * @param name    The name of the Folder.
+ * @param id      The unique id of the Folder. A new ID will be generated
+ *                if this argument is left away.
+ */
 UMLFolder::UMLFolder(const QString & name, Uml::IDType id)
-        : UMLPackage(name, id) {
+        : UMLPackage(name, id)
+{
     init();
 }
 
-UMLFolder::~UMLFolder() {
+/**
+ * Empty destructor.
+ */
+UMLFolder::~UMLFolder()
+{
+    // TODO : check if safe
+    while ( !m_diagrams.isEmpty() ) {
+        delete m_diagrams.takeFirst();
+    }
 }
 
-void UMLFolder::init() {
+/**
+ * Initializes key variables of the class.
+ */
+void UMLFolder::init()
+{
     m_BaseType = Uml::ot_Folder;
-    m_diagrams.setAutoDelete(true);
+    // Porting to QList. No autodelete supported. TODO: check if all elements of m_diagrams are properly disposed
+    //m_diagrams.setAutoDelete(true);
     UMLObject::setStereotype("folder");
 }
 
-UMLObject* UMLFolder::clone() const {
+/**
+ * Make a clone of this object.
+ */
+UMLObject* UMLFolder::clone() const
+{
     UMLFolder *clone = new UMLFolder();
     UMLObject::copyInto(clone);
     return clone;
 }
 
-void UMLFolder::setLocalName(const QString& localName) {
+/**
+ * Set the localized name of this folder.
+ * This is set for the predefined root views (Logical,
+ * UseCase, Component, Deployment, EntityRelationship,
+ * and the Datatypes folder inside the Logical View.)
+ */
+void UMLFolder::setLocalName(const QString& localName)
+{
     m_localName = localName;
 }
 
-QString UMLFolder::getLocalName() {
+/**
+ * Return the localized name of this folder.
+ * Only useful for the predefined root folders.
+ */
+QString UMLFolder::getLocalName()
+{
     return m_localName;
 }
 
-void UMLFolder::addView(UMLView *view) {
+/**
+ * Add a view to the diagram list.
+ */
+void UMLFolder::addView(UMLView *view)
+{
     m_diagrams.append(view);
 }
 
-void UMLFolder::removeView(UMLView *view) {
+/**
+ * Remove a view from the diagram list.
+ */
+void UMLFolder::removeView(UMLView *view)
+{
     // m_diagrams is set to autodelete!
-    m_diagrams.remove(view);
+    m_diagrams.removeAll(view);
+    delete view;
 }
 
-void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested) {
+/**
+ * Append the views in this folder to the given diagram list.
+ * @param viewList       The UMLViewList to which to append the diagrams.
+ * @param includeNested  Whether to include diagrams from nested folders
+ *                       (default: true.)
+ */
+void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
+{
     if (includeNested) {
-        UMLObject *o;
-        for (UMLObjectListIt oit(m_objects); (o = oit.current()) != NULL; ++oit) {
+        foreach (UMLObject* o, m_objects ) {
             if (o->getBaseType() == Uml::ot_Folder) {
                 UMLFolder *f = static_cast<UMLFolder*>(o);
                 f->appendViews(viewList);
             }
         }
     }
-    UMLView *v;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit)
+    foreach (UMLView* v, m_diagrams )
         viewList.append(v);
 }
 
-void UMLFolder::activateViews() {
-    UMLObject *o;
-    for (UMLObjectListIt oit(m_objects); (o = oit.current()) != NULL; ++oit) {
+/**
+ * Acivate the views in this folder.
+ * "Activation": Some widgets require adjustments after loading from file,
+ * those are done here.
+ */
+void UMLFolder::activateViews()
+{
+    foreach (UMLObject* o, m_objects ) {
         if (o->getBaseType() == Uml::ot_Folder) {
             UMLFolder *f = static_cast<UMLFolder*>(o);
             f->activateViews();
         }
     }
-    UMLView *v;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit)
+
+    foreach (UMLView* v, m_diagrams)
         v->activateAfterLoad();
     // Make sure we have a treeview item for each diagram.
     // It may happen that we are missing them after switching off tabbed widgets.
@@ -94,21 +152,27 @@ void UMLFolder::activateViews() {
     if (optionState.generalState.tabdiagrams)
         return;
     UMLListView *lv = UMLApp::app()->getListView();
-    for (UMLViewListIt it(m_diagrams); (v = it.current()) != NULL; ++it) {
+    foreach (UMLView* v,  m_diagrams ) {
         if (lv->findItem(v->getID()) != NULL)
             continue;
         lv->createDiagramItem(v);
     }
 }
 
-UMLView *UMLFolder::findView(Uml::IDType id) {
-    UMLView *v = NULL;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit) {
+/**
+ * Seek a view of the given ID in this folder.
+ * @param id   ID of the view to find.
+ * @return     Pointer to the view if found, NULL if no view found.
+ */
+UMLView *UMLFolder::findView(Uml::IDType id)
+{
+    foreach (UMLView* v, m_diagrams ) {
         if (v->getID() == id)
             return v;
     }
-    UMLObject *o;
-    for (UMLObjectListIt oit(m_objects); (o = oit.current()) != NULL; ++oit) {
+
+    UMLView* v = NULL;
+    foreach (UMLObject* o, m_objects ) {
         if (o->getBaseType() != Uml::ot_Folder)
             continue;
         UMLFolder *f = static_cast<UMLFolder*>(o);
@@ -119,15 +183,23 @@ UMLView *UMLFolder::findView(Uml::IDType id) {
     return v;
 }
 
-UMLView *UMLFolder::findView(Uml::Diagram_Type type, const QString &name, bool searchAllScopes) {
-    UMLView *v = NULL;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit) {
+/**
+ * Seek a view by the type and name given.
+ * @param type              The type of view to find.
+ * @param name              The name of the view to find.
+ * @param searchAllScopes   Search in all subfolders (default: true.)
+ * @return  Pointer to the view found, or NULL if not found.
+ */
+UMLView *UMLFolder::findView(Uml::Diagram_Type type, const QString &name, bool searchAllScopes)
+{
+    foreach (UMLView* v, m_diagrams ) {
         if (v->getType() == type && v->getName() == name)
             return v;
     }
+
+    UMLView* v = NULL;
     if (searchAllScopes) {
-        UMLObject *o;
-        for (UMLObjectListIt oit(m_objects); (o = oit.current()) != NULL; ++oit) {
+        foreach (UMLObject* o, m_objects  ) {
             if (o->getBaseType() != Uml::ot_Folder)
                 continue;
             UMLFolder *f = static_cast<UMLFolder*>(o);
@@ -139,23 +211,29 @@ UMLView *UMLFolder::findView(Uml::Diagram_Type type, const QString &name, bool s
     return v;
 }
 
-void UMLFolder::setViewOptions(const Settings::OptionState& optionState) {
+/**
+ * Set the options for the views in this folder.
+ */
+void UMLFolder::setViewOptions(const Settings::OptionState& optionState)
+{
     // for each view update settings
-    UMLView *v;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit)
+    foreach (UMLView* v, m_diagrams )
         v->setOptionState(optionState);
 }
 
-void UMLFolder::removeAllViews() {
-    UMLObject *o;
-    for (UMLObjectListIt oit(m_objects); (o = oit.current()) != NULL; ++oit) {
+/**
+ * Remove all views in this folder.
+ */
+void UMLFolder::removeAllViews()
+{
+    foreach (UMLObject* o, m_objects) {
         if (o->getBaseType() != Uml::ot_Folder)
             continue;
         UMLFolder *f = static_cast<UMLFolder*>(o);
         f->removeAllViews();
     }
-    UMLView *v = NULL;
-    for (UMLViewListIt vit(m_diagrams); (v = vit.current()) != NULL; ++vit) {
+
+    foreach (UMLView* v, m_diagrams ) {
         // TODO ------------------ check this code - bad: calling back to UMLDoc::removeView()
         v->removeAllAssociations(); // note : It may not be apparent, but when we remove all associations
         // from a view, it also causes any UMLAssociations that lack parent
@@ -163,32 +241,54 @@ void UMLFolder::removeAllViews() {
         // this document.
         UMLApp::app()->getDocument()->removeView(v, false);
     }
-    m_diagrams.clear();
+
+    // m_diagrams.clear()
+    while ( !m_diagrams.empty() ) {
+        delete m_diagrams.takeFirst();
+    }
 }
 
-void UMLFolder::setFolderFile(const QString& fileName) {
+/**
+ * Set the folder file name for a separate submodel.
+ */
+void UMLFolder::setFolderFile(const QString& fileName)
+{
     m_folderFile = fileName;
 }
 
-QString UMLFolder::getFolderFile() {
+/**
+ * Get the folder file name for a separate submodel.
+ */
+QString UMLFolder::getFolderFile()
+{
     return m_folderFile;
 }
 
-void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement) {
+/**
+ * Auxiliary to saveToXMI(): Save the contained objects and diagrams.
+ * Can be used regardless of whether saving to the main model file
+ * or to an external folder file (see m_folderFile.)
+ */
+void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement)
+{
     QDomElement ownedElement = qDoc.createElement("UML:Namespace.ownedElement");
-    UMLObject *obj;
+    UMLObject *obj = NULL;
     // Save contained objects if any.
-    for (UMLObjectListIt oit(m_objects); (obj = oit.current()) != NULL; ++oit)
+    for (UMLObjectListIt oit(m_objects); oit.hasNext(); ) {
+        obj = oit.next();
         obj->saveToXMI (qDoc, ownedElement);
+    }
     // Save asscociations if any.
-    for (UMLObjectListIt ait(m_List); (obj = ait.current()) != NULL; ++ait)
+    for (UMLObjectListIt ait(m_List); ait.hasNext(); ) {
+        obj = ait.next();
         obj->saveToXMI (qDoc, ownedElement);
+    }
     qElement.appendChild(ownedElement);
     // Save diagrams to `extension'.
     if (m_diagrams.count()) {
         QDomElement diagramsElement = qDoc.createElement("diagrams");
-        UMLView *pView;
-        for (UMLViewListIt vit(m_diagrams); (pView = vit.current()) != NULL; ++vit) {
+
+        foreach (UMLView* pView, m_diagrams ) {
             pView->saveToXMI(qDoc, diagramsElement);
         }
         QDomElement extension = qDoc.createElement("XMI.extension");
@@ -198,7 +298,14 @@ void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement) {
     }
 }
 
-void UMLFolder::save(QDomDocument& qDoc, QDomElement& qElement) {
+/**
+ * Auxiliary to saveToXMI(): Creates a <UML:Model> element when saving
+ * a predefined modelview, or a <UML:Package> element when saving a
+ * user created folder. Invokes saveContents() with the newly created
+ * element.
+ */
+void UMLFolder::save(QDomDocument& qDoc, QDomElement& qElement)
+{
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     QString elementName("UML:Package");
     const Uml::Model_Type mt = umldoc->rootFolderType(this);
@@ -209,7 +316,13 @@ void UMLFolder::save(QDomDocument& qDoc, QDomElement& qElement) {
     qElement.appendChild(folderElement);
 }
 
-void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
+/**
+ * Creates a UML:Model or UML:Package element:
+ * UML:Model is created for the predefined fixed folders,
+ * UML:Package with stereotype "folder" is created for all else.
+ */
+void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+{
     if (m_folderFile.isEmpty()) {
         save(qDoc, qElement);
         return;
@@ -217,13 +330,12 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
     // See if we can create the external file.
     // If not then internalize the folder.
     UMLDoc *umldoc = UMLApp::app()->getDocument();
-    QString fileName = umldoc->URL().directory() + '/' + m_folderFile;
+    QString fileName = umldoc->url().directory() + '/' + m_folderFile;
     QFile file(fileName);
-    if (!file.open(IO_WriteOnly)) {
-        kError() << "UMLFolder::saveToXMI(" << m_folderFile << "): "
-            << "cannot create file, contents will be saved in main model file"
-            << endl;
-        m_folderFile = QString::null;
+    if (!file.open(QIODevice::WriteOnly)) {
+        uError() << m_folderFile << ": "
+            << "cannot create file, contents will be saved in main model file";
+        m_folderFile.clear();
         save(qDoc, qElement);
         return;
     }
@@ -247,18 +359,23 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement) {
     folderRoot = folderDoc.createElement("external_file");
     folderRoot.setAttribute("name", m_Name);
     folderRoot.setAttribute("filename", m_folderFile);
-    folderRoot.setAttribute("mainModel", umldoc->URL().fileName());
+    folderRoot.setAttribute("mainModel", umldoc->url().fileName());
     folderRoot.setAttribute("parentId", ID2STR(m_pUMLPackage->getID()));
     folderRoot.setAttribute("parent", m_pUMLPackage->getFullyQualifiedName("::", true));
     saveContents(folderDoc, folderRoot);
     folderDoc.appendChild(folderRoot);
     QTextStream stream(&file);
-    stream.setEncoding(QTextStream::UnicodeUTF8);
+    stream.setCodec("UTF-8");
     stream << folderDoc.toString();
     file.close();
 }
 
-bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams) {
+/**
+ * Auxiliary to load():
+ * Load the diagrams from the "diagrams" in the <XMI.extension>
+ */
+bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
+{
     const Settings::OptionState optionState = Settings::getOptionState();
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     bool totalSuccess = true;
@@ -266,8 +383,7 @@ bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams) {
          diagrams = diagrams.nextSibling(), diagram = diagrams.toElement()) {
         QString tag = diagram.tagName();
         if (tag != "diagram") {
-            kDebug() << "UMLFolder::loadDiagramsFromXMI: ignoring "
-                << tag << " in <diagrams>" << endl;
+            uDebug() << "ignoring " << tag << " in <diagrams>";
             continue;
         }
         UMLView * pView = new UMLView(this);
@@ -283,25 +399,35 @@ bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams) {
     return totalSuccess;
 }
 
-bool UMLFolder::loadFolderFile(const QString& path) {
+/**
+ * Folders in the listview can be marked such that their contents
+ * are saved to a separate file.
+ * This method loads the separate folder file.
+ * CAVEAT: This is not XMI standard compliant.
+ * If standard compliance is an issue then avoid folder files.
+ * @param path  Fully qualified file name, i.e. absolute directory
+ *              plus file name.
+ * @return   True for success.
+ */
+bool UMLFolder::loadFolderFile(const QString& path)
+{
     QFile file(path);
     if (!file.exists()) {
-        KMessageBox::error(0, i18n("The folderfile %1 does not exist.").arg(path), i18n("Load Error"));
+        KMessageBox::error(0, i18n("The folderfile %1 does not exist.", path), i18n("Load Error"));
         return false;
     }
-    if (!file.open(IO_ReadOnly)) {
-        KMessageBox::error(0, i18n("The folderfile %1 cannot be opened.").arg(path), i18n("Load Error"));
+    if (!file.open(QIODevice::ReadOnly)) {
+        KMessageBox::error(0, i18n("The folderfile %1 cannot be opened.", path), i18n("Load Error"));
         return false;
     }
     QTextStream stream(&file);
-    QString data = stream.read();
+    QString data = stream.readAll();
     file.close();
     QDomDocument doc;
     QString error;
     int line;
     if (!doc.setContent( data, false, &error, &line)) {
-        kError() << "UMLFolder::loadFolderFile: Can't set content:"
-            << error << " line:" << line << endl;
+        uError() << "Can not set content:" << error << " line:" << line;
         return false;
     }
     QDomNode rootNode = doc.firstChild();
@@ -309,20 +435,23 @@ bool UMLFolder::loadFolderFile(const QString& path) {
         rootNode = rootNode.nextSibling();
     }
     if (rootNode.isNull()) {
-        kError() << "UMLFolder::loadFolderFile: Root node is Null" << endl;
+        uError() << "Root node is Null";
         return false;
     }
     QDomElement element = rootNode.toElement();
     QString type = element.tagName();
     if (type != "external_file") {
-        kError() << "UMLFolder::loadFolderFile: Root node has unknown type "
-            << type << endl;
+        uError() << "Root node has unknown type " << type;
         return false;
     }
     return load(element);
 }
 
-bool UMLFolder::load(QDomElement& element) {
+/**
+ * Loads the UML:Component element.
+ */
+bool UMLFolder::load(QDomElement& element)
+{
     UMLDoc *umldoc = UMLApp::app()->getDocument();
     bool totalSuccess = true;
     for (QDomNode node = element.firstChild(); !node.isNull();
@@ -339,8 +468,8 @@ bool UMLFolder::load(QDomElement& element) {
             // are ownedElements anyway.
             // Therefore these tags are not further interpreted.
             if (! load(tempElement)) {
-                kDebug() << "An error happened while loading the " << type
-                    << " of the " << m_Name << endl;
+                uDebug() << "An error happened while loading the " << type
+                    << " of the " << m_Name;
                 totalSuccess = false;
             }
             continue;
@@ -354,14 +483,13 @@ bool UMLFolder::load(QDomElement& element) {
                     if (!loadDiagramsFromXMI(diagramNode))
                         totalSuccess = false;
                 } else if (xtag == "external_file") {
-                    const QString rootDir(umldoc->URL().directory());
+                    const QString rootDir(umldoc->url().directory());
                     QString fileName = el.attribute("name", "");
                     const QString path(rootDir + '/' + fileName);
                     if (loadFolderFile(path))
                         m_folderFile = fileName;
                 } else {
-                    kDebug() << "UMLFolder::load(" << m_Name
-                        << "): ignoring XMI.extension " << xtag << endl;
+                    uDebug() << m_Name << ": ignoring XMI.extension " << xtag;
                     continue;
                 }
             }
@@ -386,16 +514,14 @@ bool UMLFolder::load(QDomElement& element) {
             Uml::IDType id = STR2ID(idStr);
             pObject = umldoc->findObjectById(id);
             if (pObject) {
-                kDebug() << "UMLFolder::load: object " << idStr
-                  << "already exists" << endl;
+                uDebug() << "object " << idStr << "already exists";
             }
         }
         if (pObject == NULL) {
             QString stereoID = tempElement.attribute("stereotype", "");
             pObject = Object_Factory::makeObjectFromXMI(type, stereoID);
             if (!pObject) {
-                kWarning() << "UMLFolder::load: "
-                    << "Unknown type of umlobject to create: " << type << endl;
+                uWarning() << "Unknown type of umlobject to create: " << type;
                 continue;
             }
         }
